pub struct ContractDeployer<'a, W> { /* private fields */ }Expand description
Builder for deploying new contract instances.
Created with a contract artifact and wallet reference. Use
ContractDeployer::deploy to produce a DeployMethod for a
specific set of constructor arguments.
Implementations
Sourceimpl<'a, W: Wallet> ContractDeployer<'a, W>
impl<'a, W: Wallet> ContractDeployer<'a, W>
Sourcepub fn new(artifact: ContractArtifact, wallet: &'a W) -> Self
pub fn new(artifact: ContractArtifact, wallet: &'a W) -> Self
Create a new deployer for the given artifact and wallet.
Sourcepub const fn with_public_keys(self, keys: PublicKeys) -> Self
pub const fn with_public_keys(self, keys: PublicKeys) -> Self
Set the public keys for the deployed instance.
Sourcepub fn with_constructor_name(self, name: impl Into<String>) -> Self
pub fn with_constructor_name(self, name: impl Into<String>) -> Self
Set the constructor function name (defaults to "constructor").
Sourcepub fn deploy(self, args: Vec<AbiValue>) -> Result<DeployMethod<'a, W>, Error>
pub fn deploy(self, args: Vec<AbiValue>) -> Result<DeployMethod<'a, W>, Error>
Create a DeployMethod for the given constructor arguments.
Validates the selected initializer, when present. Contracts with no initializer are allowed as long as no constructor arguments are passed.