decode_from_abi

Function decode_from_abi 

pub fn decode_from_abi(
    types: &[AbiType],
    fields: &[Fr],
) -> Result<AbiDecoded, Error>
Decode field elements back into typed ABI values.

types is the list of return types from a function’s ABI. fields is the flat array of field elements returned by the function.